#define ERROR_HANDLER_H

/****************************************************************

    Copyright (c) 1996-1997 Fred Pesch

    This program is free software; you can redistribute it 
    and/or modify it under the terms of the GNU General 
    Public License as published by the Free Software 
    Foundation (version 2 of the License).

    This program is distributed in the hope that it will 
    be useful, but WITHOUT ANY WARRANTY; without even the 
    implied warranty of MERCHANTABILITY or FITNESS FOR A 
    PARTICULAR PURPOSE.  See the GNU General Public License 
    for more details.

    For a copy of the GNU General Public License, write to the 
    Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
    MA 02139, USA.

****************************************************************/

#include <Xm/Xm.h>
#include <stdio.h>
#include <stdlib.h>
#include "interface.h"

Widget W_MessageText;
Widget W_ConfirmText;

int ConfirmDialogOnScreen;
int ConfirmDialogReturnValue;

void MessageDialog(char *title, char *message) 
{
  XmString xmtitle;

  xmtitle = XmStringCreateSimple(title);

  XtVaSetValues(W_MessageText, XmNvalue, message, NULL, NULL);
  XtVaSetValues(W_MessageDialog, XmNdialogTitle, xmtitle, NULL, NULL);
  XmStringFree(xmtitle);
  XtManageChild(W_MessageDialog);
}

int ConfirmDialog(char *title, char *message) 
{
  XmString xmtitle;
  XEvent event;

  xmtitle = XmStringCreateSimple(title);

  XtVaSetValues(W_ConfirmText, XmNvalue, message, NULL, NULL);
  XtVaSetValues(W_ConfirmDialog, XmNdialogTitle, xmtitle, NULL, NULL);
  XmStringFree(xmtitle);

  ConfirmDialogOnScreen=1;
  XtManageChild(W_ConfirmDialog);
  XtAddGrab(XtParent(W_ConfirmDialog), True, False);
  while(ConfirmDialogOnScreen || XtAppPending(AppContext)) {
    XtAppNextEvent(AppContext, &event);
    XtDispatchEvent(&event);
  }
  return ConfirmDialogReturnValue;
}

void NonFatalError(char *module, char *fctname, char *message)
{
  fprintf(stderr, "fof : Non-Fatal Error in module %s\n", module);
  fprintf(stderr, "                      in function %s()\n\n",fctname);
  fprintf(stderr, "Error : %s\n\n", message);
}

void FatalError(char *module, char *fctname, char *message)
{
  fprintf(stderr, "fof : Fatal Error in module %s\n", module);
  fprintf(stderr, "                  in function %s()\n\n",fctname);
  fprintf(stderr, "Error : %s\n\n", message);
  fprintf(stderr, "Kill fof process...\n\n");
  exit(1);
}

void InitMessageDialog(void)
{
  Pixmap pixmap;
  Screen *screen;
  Display *display;
  Pixel fg, bg;
  Widget w_temp;

  /* Dir Pixmaps    :  next in .fofrc  or   Fofrc.default */

  display = XtDisplay(W_MessageDialog);
  screen = XtScreen(W_MessageDialog);

  XtVaGetValues(W_MessageDialog, XmNforeground, &fg, XmNbackground, &bg, NULL, NULL);

  pixmap = XmGetPixmap(screen, "xpm/warning.xbm", fg, bg);

  w_temp = NULL;
  w_temp= XtNameToWidget(W_MessageDialog, "*MessagePixmap");
 if(w_temp==NULL)
   FatalError("error_handler.c", "InitMessageDialog", "Cannot find pixmap widget");
 
 XtVaSetValues(w_temp, XmNlabelPixmap, pixmap, NULL, NULL);

  W_MessageText = NULL;
  W_MessageText= XtNameToWidget(W_MessageDialog, "*MessageText");
 if(w_temp==NULL)
   FatalError("error_handler.c", "InitMessageDialog", "Cannot find text widget");
}

void ConfirmYesButtonCB(Widget w_button, XtPointer app_data, XtPointer widget_data)
{
  ConfirmDialogOnScreen = 0;
  XtRemoveGrab(XtParent(W_ConfirmDialog));
  XtUnmanageChild(W_ConfirmDialog);
  ConfirmDialogReturnValue = 1;
}

void ConfirmNoButtonCB(Widget w_button, XtPointer app_data, XtPointer widget_data)
{  
  ConfirmDialogOnScreen = 0;
  XtRemoveGrab(XtParent(W_ConfirmDialog));
  XtUnmanageChild(W_ConfirmDialog);
  ConfirmDialogReturnValue = 0;
}

void InitConfirmDialog(void)
{
  Pixmap pixmap;
  Screen *screen;
  Display *display;
  Pixel fg, bg;
  Widget w_temp;

  /* Dir Pixmaps    :  next in .fofrc  or   Fofrc.default */

  display = XtDisplay(W_ConfirmDialog);
  screen = XtScreen(W_ConfirmDialog);

  XtVaGetValues(W_ConfirmDialog, XmNforeground, &fg, XmNbackground, &bg, NULL, NULL);

  pixmap = XmGetPixmap(screen, "xpm/asking.xpm", fg, bg);

  w_temp = NULL;
  w_temp= XtNameToWidget(W_ConfirmDialog, "*ConfirmPixmap");
 if(w_temp==NULL)
   FatalError("error_handler.c", "InitConfirmDialog", "Cannot find pixmap widget");
 
 XtVaSetValues(w_temp, XmNlabelPixmap, pixmap, NULL, NULL);

  W_ConfirmText = NULL;
  W_ConfirmText= XtNameToWidget(W_ConfirmDialog, "*ConfirmText");
 if(w_temp==NULL)
   FatalError("error_handler.c", "InitConfirmDialog", "Cannot find text widget");

  w_temp = NULL;
  w_temp= XtNameToWidget(W_ConfirmDialog, "*ConfirmYesButton");
 if(w_temp==NULL)
   FatalError("error_handler.c", "InitConfirmDialog", "Cannot find Yes button widget");

 XtAddCallback(w_temp, XmNactivateCallback, ConfirmYesButtonCB, NULL);

  w_temp = NULL;
  w_temp= XtNameToWidget(W_ConfirmDialog, "*ConfirmNoButton");
 if(w_temp==NULL)
   FatalError("error_handler.c", "InitConfirmDialog", "Cannot find No button widget");

 XtAddCallback(w_temp, XmNactivateCallback, ConfirmNoButtonCB, NULL);
}







